{{/* vim: set filetype=mustache: */}}
{{/* Expand the name of the chart. */}}
{{- define "cnc.name" -}}
{{- default .Chart.Name .Values.nameOverride | trunc 63 | trimSuffix "-" -}}
{{- end -}}

{{/* Create a default fully qualified app name.
We truncate at 63 chars because some Kubernetes name fields are limited to this (by the DNS naming spec).
If release name contains chart name it will be used as a full name. */}}
{{- define "cnc.fullname" -}}
{{- if .Values.fullnameOverride -}}
{{- .Values.fullnameOverride | trunc 63 | trimSuffix "-" -}}
{{- else -}}
{{- $name := default .Chart.Name .Values.nameOverride -}}
{{- .Release.Name | trunc 63 | trimSuffix "-" -}}
{{- end -}}
{{- end -}}

{{/* Create chart name and version as used by the chart label. */}}
{{- define "cnc.chart" -}}
{{- printf "%s-%s" .Chart.Name .Chart.Version | replace "+" "_" | trunc 63 | trimSuffix "-" -}}
{{- end -}}

{{/* Common labels */}}
{{- define "chart.labels" -}}
app.kubernetes.io/name: {{ include "cnc.name" . }}
helm.sh/chart: {{ include "cnc.chart" . }}
app.kubernetes.io/instance: {{ .Release.Name }}
{{- if .Chart.AppVersion }}
app.kubernetes.io/version: "{{ include "cnc.app-version" . }}"
{{- end }}
app.kubernetes.io/managed-by: {{ .Release.Service }}
chart: {{ .Chart.Name | quote }}
{{- end -}}

{{- define "service.labels" -}}
helm.sh/chart: {{ include "cnc.chart" . }}
{{ include "service.selectorLabels" . }}
{{- if .Chart.AppVersion }}
app.kubernetes.io/version: "{{ include "cnc.app-version" . }}"
{{- end }}
app.kubernetes.io/managed-by: {{ .Release.Service }}
{{- end }}

{{- define "service.selectorLabels" -}}
app.kubernetes.io/name: {{ .serviceName }}
app.kubernetes.io/instance: {{ .Release.Name }}
app.kubernetes.io/component: {{ .serviceName }} # TODO what should this be?
app.kubernetes.io/part-of: cnc
{{- end }}

{{- define "cnc.app-version" -}}
{{- printf "%s" .Chart.AppVersion | replace "+" "_" | replace ":" "_" | trunc 63 | trimSuffix "-" }}
{{- end }}

{{/*
https://github.com/openstack/openstack-helm-infra/blob/master/helm-toolkit/templates/utils/_joinListWithComma.tpl
*/}}
{{- define "helm-toolkit.utils.joinListWithComma" -}}
{{- $local := dict "first" true -}}
{{- range $k, $v := . -}}{{- if not $local.first -}},{{- end -}}{{- $v -}}{{- $_ := set $local "first" false -}}{{- end -}}
{{- end -}}

{{- define "cnc.image.name" -}}
    {{ printf "%s/%s:%s" (default .Values.imageRegistry (index .Values .serviceName).imageRegistry) (required "missing image name" (index .Values .serviceName).image) (default .Values.imageVersion (index .Values .serviceName).version) | quote }}
{{- end }}


{{- define "cnc.postgres.secret" }}
apiVersion: v1
kind: Secret
metadata:
  name: {{ include "cnc.fullname" . }}-{{ .serviceName }}-db-creds
  namespace: {{ .Release.Namespace }}
  annotations:
    helm.sh/hook-weight: "-13"
    helm.sh/hook: pre-upgrade, pre-install
type: Opaque
stringData:
  host: {{ (index .Values .serviceName).postgres.host | default .Values.postgres.host | quote }}
  port: {{ (index .Values .serviceName).postgres.port | default .Values.postgres.port | quote }}
  username: {{ (index .Values .serviceName).postgres.user | default .Values.postgres.user | quote }}
  password: {{ (index .Values .serviceName).postgres.password | default .Values.postgres.password | quote }}
  database: {{ (index .Values .serviceName).postgres.database | quote }}
{{- end }}


{{- define "cnc.postgres.environment" }}
- name: POSTGRES_HOST
  valueFrom:
    secretKeyRef:
      name: {{ include "cnc.fullname" . }}-{{ .serviceName }}-db-creds
      key: "host"
- name: POSTGRES_PORT
  valueFrom:
    secretKeyRef:
      name: {{ include "cnc.fullname" . }}-{{ .serviceName }}-db-creds
      key: "port"
- name: POSTGRES_USERNAME
  valueFrom:
    secretKeyRef:
      name: {{ include "cnc.fullname" . }}-{{ .serviceName }}-db-creds
      key: "username"
- name: POSTGRES_PASSWORD
  valueFrom:
    secretKeyRef:
      name: {{ include "cnc.fullname" . }}-{{ .serviceName }}-db-creds
      key: "password"
- name: POSTGRES_DATABASE
  valueFrom:
    secretKeyRef:
      name: {{ include "cnc.fullname" . }}-{{ .serviceName }}-db-creds
      key: "database"
{{- end }}

{{- define "cnc.pg.environment" }}
{{- if or (eq .serviceName "cnc-db-admin") (eq .serviceName "cim-database-setup") }}
- name: PGHOST
  valueFrom:
    secretKeyRef:
      name: {{ include "cnc.fullname" . }}-cim-db-creds
      key: "host"
- name: PGPORT
  valueFrom:
    secretKeyRef:
      name: {{ include "cnc.fullname" . }}-cim-db-creds
      key: "port"
- name: PGUSER
  valueFrom:
    secretKeyRef:
      name: {{ include "cnc.fullname" . }}-cim-db-creds
      key: "username"
- name: PGPASSWORD
  valueFrom:
    secretKeyRef:
      name: {{ include "cnc.fullname" . }}-cim-db-creds
      key: "password"
- name: PGDATABASE
  value: "postgres"
- name: CIM_WEBAPP_PG_USER
  valueFrom:
    secretKeyRef:
      name: {{ include "cnc.fullname" . }}-cim-db-creds
      key: "username"
- name: CIM_WEBAPP_PG_PASSWORD
  valueFrom:
    secretKeyRef:
      name: {{ include "cnc.fullname" . }}-cim-db-creds
      key: "password"
- name: CIM_WEBAPP_PG_DATABASE
  valueFrom:
    secretKeyRef:
      name: {{ include "cnc.fullname" . }}-cim-db-creds
      key: "database"
{{- else }}
- name: PGHOST
  valueFrom:
    secretKeyRef:
      name: {{ include "cnc.fullname" . }}-{{ .serviceName }}-db-creds
      key: "host"
- name: PGPORT
  valueFrom:
    secretKeyRef:
      name: {{ include "cnc.fullname" . }}-{{ .serviceName }}-db-creds
      key: "port"
- name: PGUSER
  valueFrom:
    secretKeyRef:
      name: {{ include "cnc.fullname" . }}-{{ .serviceName }}-db-creds
      key: "username"
- name: PGPASSWORD
  valueFrom:
    secretKeyRef:
      name: {{ include "cnc.fullname" . }}-{{ .serviceName }}-db-creds
      key: "password"
- name: PGDATABASE
  valueFrom:
    secretKeyRef:
      name: {{ include "cnc.fullname" . }}-{{ .serviceName }}-db-creds
      key: "database"
{{- end }}
{{- end }}